.. Copyright 2016, 2020 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap
---------------------------

.. automodule:: reahl.web.bootstrap


.. toctree::
   :maxdepth: 1

   Widgets related to the main page <page>
   Basic Widgets <ui>
   Forms and user input <forms>
   Layout and responsive sizing <grid>
   Uploading files <files>
   Tables <tables>
   Navs <navs>
   Navbars <navbar>
   Pagination of long lists <pagination>
   Tabbed panel <tabbedpanel>
   Carousel <carousel>

   
   
